In the post_reset function, if the fast reset didn't succeed, we
are not clearing the fast_reset flag, which prevents firmware
sections from being reloaded. While at it, use panthor_fw_stop()
instead of manually writing DISABLE to the MCU_CONTROL register.

Fixes: 2718d91816ee ("drm/panthor: Add the FW logical block")
Signed-off-by: Boris Brezillon <boris.brezil...@collabora.com>
---
 drivers/gpu/drm/panthor/panthor_fw.c | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/drivers/gpu/drm/panthor/panthor_fw.c 
b/drivers/gpu/drm/panthor/panthor_fw.c
index 181395e2859a..fedf9627453f 100644
--- a/drivers/gpu/drm/panthor/panthor_fw.c
+++ b/drivers/gpu/drm/panthor/panthor_fw.c
@@ -1083,10 +1083,11 @@ int panthor_fw_post_reset(struct panthor_device *ptdev)
                if (!ret)
                        goto out;
 
                /* Force a disable, so we get a fresh boot on the next
                 * panthor_fw_start() call.
                 */
-               gpu_write(ptdev, MCU_CONTROL, MCU_CONTROL_DISABLE);
+               panthor_fw_stop(ptdev);
+               ptdev->fw->fast_reset = false;
                drm_err(&ptdev->base, "FW fast reset failed, trying a slow 
reset");
        }
@@ -1083,10 +1083,11 @@ int panthor_fw_post_reset(struct panthor_device *ptdev)
                        goto out;
 
-               /* Force a disable, so we get a fresh boot on the next
-                * panthor_fw_start() call.
+               /* Forcibly reset the MCU and force a slow reset, so we get a
+                * fresh boot on the next panthor_fw_start() call.
                 */
 
-- 
2.44.0

Reply via email to